Index: main/jitterbuf.c
===================================================================
--- main/jitterbuf.c	(revision 355982)
+++ main/jitterbuf.c	(working copy)
@@ -127,6 +127,7 @@
 	long delay = now - (ts - jb->info.resync_offset);
 	long threshold = 2 * jb->info.jitter + jb->info.conf.resync_threshold;
 	long kicked;
+	long numts = 0;
 
 	/* don't add special/negative times to history */
 	if (ts <= 0) 
@@ -154,6 +155,23 @@
 		}
 	}
 
+	/* Check for overfill of the buffer */
+	if (jb->frames) {
+		numts = jb->frames->prev->ts - jb->frames->ts;
+	}
+
+	if (numts >= jb->info.conf.max_jitterbuf) {
+		if (!jb->dropem) {
+			ast_debug(1, "Attempting to exceed Jitterbuf max %ld timeslots\n",
+				jb->info.conf.max_jitterbuf);
+			jb->dropem = 1;
+		}
+		jb->info.frames_dropped++;
+		return JB_DROP;
+	} else {
+		jb->dropem = 0;
+	}
+
 	kicked = jb->history[jb->hist_ptr % JB_HISTORY_SZ];
 
 	jb->history[(jb->hist_ptr++) % JB_HISTORY_SZ] = delay;
@@ -506,26 +524,8 @@
 
 enum jb_return_code jb_put(jitterbuf *jb, void *data, const enum jb_frame_type type, long ms, long ts, long now) 
 {
-	long numts;
-
 	jb_dbg2("jb_put(%x,%x,%ld,%ld,%ld)\n", jb, data, ms, ts, now);
 
-	numts = 0;
-	if (jb->frames)
-		numts = jb->frames->prev->ts - jb->frames->ts;
-
-	if (numts >= jb->info.conf.max_jitterbuf) {
-		if (!jb->dropem) {
-			ast_debug(1, "Attempting to exceed Jitterbuf max %ld timeslots\n",
-				jb->info.conf.max_jitterbuf);
-			jb->dropem = 1;
-		}
-		jb->info.frames_dropped++;
-		return JB_DROP;
-	} else {
-		jb->dropem = 0;
-	}
-
 	if (type == JB_TYPE_VOICE) {
 		/* presently, I'm only adding VOICE frames to history and drift calculations; mostly because with the
 		 * IAX integrations, I'm sending retransmitted control frames with their awkward timestamps through */

